/* Use of this source code is governed by a BSD-style
 * license that can be found in the LICENSE file.
 * Copyright 2001-2019 The ovh-ttyrec Authors. All rights reserved.
 *
 * This work is based on the original ttyrec, whose license text
 * can be found below unmodified.
 *
 * Copyright (c) 2000 Satoru Takabayashi <satoru@namazu.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *    This product includes software developed by the University of
 *    California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <assert.h>
#include <errno.h>
#include <stdio.h>
#include <stdint.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <endian.h>
#include <err.h>

#include "io.h"
#include "ttyrec.h"
#include "compress.h"

#define convert_to_little_endian htole32

int read_header(FILE *fp, Header *h)
{
    uint32_t buf[3];

    if (fread_wrapper(buf, sizeof(uint32_t), 3, fp) != 3)
    {
        return 0;
    }

    h->tv.tv_sec  = convert_to_little_endian(buf[0]);
    h->tv.tv_usec = convert_to_little_endian(buf[1]);
    h->len        = convert_to_little_endian(buf[2]);

    return 1;
}


int write_header(FILE *fp, Header *h)
{
    uint32_t buf[3];

    buf[0] = convert_to_little_endian(h->tv.tv_sec);
    buf[1] = convert_to_little_endian(h->tv.tv_usec);
    buf[2] = convert_to_little_endian(h->len);

    if (fwrite_wrapper(buf, sizeof(uint32_t), 3, fp) == 0)
    {
        return 0;
    }

    return 1;
}


FILE *efopen(const char *path, const char *mode)
{
    FILE *fp = fopen(path, mode);

    if (fp == NULL)
    {
        err(EXIT_FAILURE, "%s\n", path);
    }
    return fp;
}


int edup(int oldfd)
{
    int fd = dup(oldfd);

    if (fd == -1)
    {
        err(EXIT_FAILURE, "dup failed\n");
    }
    return fd;
}


int edup2(int oldfd, int newfd)
{
    int fd = dup2(oldfd, newfd);

    if (fd == -1)
    {
        err(EXIT_FAILURE, "dup2 failed\n");
    }
    return fd;
}


FILE *efdopen(int fd, const char *mode)
{
    FILE *fp = fdopen(fd, mode);

    if (fp == NULL)
    {
        err(EXIT_FAILURE, "fdopen failed\n");
    }
    return fp;
}
